package com.muyu.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.PageQueryModel;
import com.muyu.common.system.domain.SysDictType;
import com.muyu.common.system.domain.SysLogininfor;
import com.muyu.system.domain.model.SysLogininforPageQueryModel;
import com.muyu.system.mapper.SysLogininforMapper;
import com.muyu.system.service.SysLogininforService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;

/**
 * 系统访问日志情况信息 服务层处理
 *
 * @author muyu
 */
@Service
public class SysLogininforServiceImpl extends ServiceImpl<SysLogininforMapper, SysLogininfor> implements SysLogininforService {

    @Autowired
    private SysLogininforMapper logininforMapper;

    /**
     * 新增系统登录日志
     *
     * @param logininfor 访问日志对象
     */
    @Override
    public int insertLogininfor (SysLogininfor logininfor) {
        return logininforMapper.insertLogininfor(logininfor);
    }

    /**
     * 查询系统登录日志集合
     *
     * @param logininfor 访问日志对象
     *
     * @return 登录记录集合
     */
    @Override
    public List<SysLogininfor> selectLogininforList (SysLogininfor logininfor) {
        return logininforMapper.selectLogininforList(logininfor);
    }

    /**
     * 批量删除系统登录日志
     *
     * @param infoIds 需要删除的登录日志ID
     *
     * @return 结果
     */
    @Override
    public int deleteLogininforByIds (Long[] infoIds) {
        return logininforMapper.deleteLogininforByIds(infoIds);
    }

    /**
     * 清空系统登录日志
     */
    @Override
    public void cleanLogininfor () {
        logininforMapper.cleanLogininfor();
    }

    @Override
    public PageQueryModel<SysLogininfor> pageQuery (SysLogininforPageQueryModel sysLogininforPageQueryModel) {
        LambdaQueryWrapper<SysLogininfor> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(sysLogininforPageQueryModel.getUserName()),SysLogininfor::getUserName, sysLogininforPageQueryModel.getUserName());
        queryWrapper.like(StringUtils.isNotEmpty(sysLogininforPageQueryModel.getIpaddr()),SysLogininfor::getIpaddr, sysLogininforPageQueryModel.getIpaddr());
        queryWrapper.eq(StringUtils.isNotEmpty(sysLogininforPageQueryModel.getStatus()),SysLogininfor::getStatus, sysLogininforPageQueryModel.getStatus());
        queryWrapper.gt(Objects.nonNull(sysLogininforPageQueryModel.getBeginTime()),SysLogininfor::getAccessTime, sysLogininforPageQueryModel.getBeginTime());
        queryWrapper.lt(Objects.nonNull(sysLogininforPageQueryModel.getEndTime()),SysLogininfor::getAccessTime, sysLogininforPageQueryModel.getEndTime());
        Page<SysLogininfor> page = this.page(sysLogininforPageQueryModel.buildPage(), queryWrapper);
        return PageQueryModel.of(page);
    }

}
